aboutsummaryrefslogtreecommitdiff
path: root/binutils
diff options
context:
space:
mode:
Diffstat (limited to 'binutils')
-rw-r--r--binutils/ChangeLog5
-rw-r--r--binutils/objcopy.c4
2 files changed, 7 insertions, 2 deletions
diff --git a/binutils/ChangeLog b/binutils/ChangeLog
index 19569d4..693e155 100644
--- a/binutils/ChangeLog
+++ b/binutils/ChangeLog
@@ -1,3 +1,8 @@
+2014-09-01 Jon TURNEY <jon.turney@dronecode.org.uk>
+
+ * objcopy.c (is_nondebug_keep_contents_section): Change
+ '.build-id' to '.buildid'.
+
2014-08-22 Richard Henderson <rth@redhat.com>
* dwarf.h (init_dwarf_regnames_aarch64): Declare.
diff --git a/binutils/objcopy.c b/binutils/objcopy.c
index 46fd8bc..3b353ad 100644
--- a/binutils/objcopy.c
+++ b/binutils/objcopy.c
@@ -1148,13 +1148,13 @@ is_nondebug_keep_contents_section (bfd *ibfd, asection *isection)
if (ibfd->xvec->flavour == bfd_target_elf_flavour)
return (elf_section_type (isection) == SHT_NOTE);
/* Always keep the .build-id section for PE/COFF.
Strictly, this should be written "always keep the section storing the debug
directory", but that may be the .text section for objects produced by some
tools, which it is not sensible to keep. */
if (ibfd->xvec->flavour == bfd_target_coff_flavour)
- return (strcmp (bfd_get_section_name (ibfd, isection), ".build-id") == 0);
+ return (strcmp (bfd_get_section_name (ibfd, isection), ".buildid") == 0);
return FALSE;
}
@@ -1148,13 +1148,13 @@ is_nondebug_keep_contents_section (bfd *ibfd, asection *isection)
if (ibfd->xvec->flavour == bfd_target_elf_flavour)
return (elf_section_type (isection) == SHT_NOTE);
- /* Always keep the .build-id section for PE/COFF.
+ /* Always keep the .buildid section for PE/COFF.
Strictly, this should be written "always keep the section storing the debug
directory", but that may be the .text section for objects produced by some